Dokumente: BDEW Forum Datenformate

Skip to main content

## Archivierte Dokumente

nach Gruppierung
Listenansicht

Titel | Gültig von | Gültig bis |
--- | --- | --- | ---
Berichte
IFTSTA MIG 1.1 | 01.10.2011 | 30.09.2012 |
IFTSTA MIG 1.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 02.04.2012 | 01.10.2011 | 30.09.2012 |
IFTSTA MIG 1.1a | 01.10.2012 | 30.09.2013 |
IFTSTA MIG 1.1a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 11.01.2013 | 01.04.2013 | 30.09.2013 |
IFTSTA MIG 1.1b | 01.10.2013 | 31.03.2014 |
IFTSTA MIG 1.2 | 01.10.2014 | 31.03.2015 |
IFTSTA MIG 1.2a | 01.04.2015 | 30.09.2017 |
IFTSTA MIG 1.2b | 01.10.2017 | 30.11.2019 |
IFTSTA MIG 1.2b Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.11.2017 | 01.10.2017 | 15.11.2018 |
IFTSTA MIG 1.2b Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 16.11.2018 | 01.10.2017 | 30.11.2019 |
IFTSTA MIG 2.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.07.2019 | 01.12.2019 | 01.10.2019 |
IFTSTA MIG 2.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 02.10.2019 | 01.12.2019 | 10.11.2019 |
IFTSTA MIG 2.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 11.11.2019 | 01.12.2019 | 16.12.2019 |
IFTSTA MIG 2.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 17.12.2019 | 17.12.2019 | 02.04.2020 |
IFTSTA MIG 2.0a | 01.04.2021 | Offen |
IFTSTA AHB 1.0 | 01.04.2011 | 30.09.2011 |
IFTSTA AHB 1.1 | 01.10.2011 | 30.09.2012 |
IFTSTA AHB 1.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 02.04.2012 | 01.10.2011 | 30.09.2012 |
IFTSTA AHB 1.1a | 01.10.2012 | 30.09.2013 |
IFTSTA AHB 1.1a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 11.01.2013 | 01.04.2013 | 30.09.2013 |
IFTSTA AHB 1.1b | 01.10.2013 | 31.03.2014 |
IFTSTA AHB 1.2 | 01.04.2014 | 30.09.2014 |
IFTSTA AHB 1.2a | 01.10.2014 | 31.03.2015 |
IFTSTA AHB 1.2a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 30.01.2015 | 30.01.2015 | 31.03.2015 |
IFTSTA AHB 1.2b | 01.04.2015 | 30.09.2015 |
IFTSTA AHB 1.2b Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 30.01.2015 | 01.04.2015 | 30.09.2015 |
IFTSTA AHB 1.2c | 01.10.2015 | 31.03.2016 |
IFTSTA AHB 1.2d | 01.04.2016 | 30.09.2017 |
IFTSTA AHB 1.2e | 01.10.2017 | 30.11.2019 |
IFTSTA AHB 1.2e Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.11.2017 | 01.10.2017 | 15.11.2018 |
IFTSTA AHB 1.2e Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 16.11.2018 | 01.10.2017 | 29.01.2019 |
IFTSTA AHB 1.2e Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 30.01.2019 | 01.10.2017 | 30.11.2019 |
IFTSTA AHB 2.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 02.10.2019 | 01.12.2019 | 10.11.2019 |
IFTSTA AHB 2.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.07.2019 | 01.12.2019 | 01.10.2019 |
IFTSTA AHB 2.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 11.11.2019 | 01.12.2019 | 02.04.2020 |
IFTSTA AHB 2.0a | 01.04.2021 | Offen |
INSRPT MIG 1.0 | 01.10.2011 | 30.09.2013 |
INSRPT MIG 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 02.04.2012 | 01.10.2011 | 30.09.2013 |
INSRPT MIG 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 28.09.2012 | 28.09.2012 | 30.09.2013 |
INSRPT MIG 1.0a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 25.07.2014 | 01.10.2014 | 31.03.2017 |
INSRPT MIG 1.0c | 01.10.2017 | 30.11.2019 |
INSRPT AHB 1.0a | 01.10.2013 | 31.03.2014 |
INSRPT AHB 1.1 | 01.04.2014 | 30.09.2014 |
INSRPT AHB 1.1a | 01.10.2014 | 31.03.2015 |
INSRPT AHB 1.1b | 01.04.2015 | 30.09.2015 |
INSRPT AHB 1.1c | 01.10.2015 | 31.03.2016 |
INSRPT AHB 1.1d | 01.04.2016 | 30.09.2017 |
INSRPT AHB 1.1e | 01.10.2017 | 30.11.2019 |
INSRPT AHB 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 02.04.2012 | 01.10.2011 | 30.09.2013 |
QUOTES MIG 1.0b | 01.04.2014 | 30.09.2014 |
UTILMD AHB GPKE / GeLi Gas 6.0e | 01.10.2016 | 30.09.2017 |
Bestellvorgang
ORDERS MIG 1.0 | 01.04.2011 | 30.09.2011 |
ORDERS MIG 1.1 | 01.10.2011 | 31.03.2013 |
ORDERS MIG 1.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 02.04.2012 | 01.10.2011 | 31.03.2013 |
ORDERS MIG 1.1a | 01.04.2013 | 30.09.2013 |
ORDERS MIG 1.1c | 01.04.2014 | 30.09.2014 |
ORDERS MIG 1.1d | 01.10.2014 | 31.03.2015 |
ORDERS MIG 1.1e | 01.04.2015 | 30.09.2015 |
ORDERS MIG 1.1f | 01.10.2015 | 31.03.2016 |
ORDERS MIG 1.1g | 01.04.2016 | 30.09.2016 |
ORDERS MIG 1.1h | 01.10.2016 | 30.09.2017 |
ORDERS MIG 1.1i | 01.10.2017 | 30.11.2019 |
ORDERS MIG 1.1i Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 26.06.2017 | 01.10.2017 | 30.11.2019 |
ORDERS MIG 1.1j | 01.12.2019 | 31.03.2020 |
ORDERS MIG 1.1j Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 11.11.2019 | 01.12.2019 | 31.03.2020 |
ORDERS AHB MaBiS 1.0 | 01.04.2011 | 30.09.2011 |
ORDERS AHB MaBiS 1.1 | 01.10.2011 | 30.09.2013 |
ORDERS AHB MaBiS 1.2 | 01.04.2014 | 30.09.2014 |
ORDERS AHB MaBiS 1.2a | 01.10.2014 | 31.03.2015 |
ORDERS AHB MaBiS 1.2b | 01.04.2015 | 30.09.2015 |
ORDERS AHB MaBiS 1.2c | 01.10.2015 | 31.03.2016 |
ORDERS AHB MaBiS 1.2d | 01.04.2016 | 30.09.2016 |
ORDERS AHB MaBiS 1.2e | 01.10.2016 | 30.09.2017 |
ORDERS AHB MaBiS 1.2f | 01.10.2017 | 30.11.2019 |
ORDRSP MIG 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 02.04.2012 | 01.10.2011 | 31.03.2013 |
ORDRSP MIG 1.1 | 01.04.2013 | 30.09.2013 |
ORDRSP MIG 1.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 13.12.2012 | 01.04.2013 | 30.09.2013 |
ORDRSP MIG 1.1b | 01.10.2014 | 31.12.2014 |
ORDRSP MIG 1.1c | 01.10.2015 | 30.09.2015 |
ORDRSP MIG 1.1d | 01.10.2015 | 31.03.2016 |
ORDRSP MIG 1.1e | 01.04.2016 | 30.09.2016 |
ORDRSP MIG 1.1f | 01.10.2016 | 30.09.2017 |
ORDRSP MIG 1.1g | 01.10.2017 | 30.11.2019 |
ORDRSP MIG 1.1g Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 26.06.2017 | 01.10.2017 | 15.11.2018 |
ORDRSP MIG 1.1g Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 16.11.2018 | 01.10.2017 | 30.11.2019 |
ORDRSP MIG 1.1i | 01.04.2021 | Offen |
ORDERS / ORDRSP AHB Geschäftsdatenanfrage 1.0 | 01.10.2011 | 31.03.2013 |
ORDERS / ORDRSP AHB Geschäftsdatenanfrage 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 02.04.2012 | 01.10.2011 | 31.03.2013 |
ORDERS / ORDRSP AHB Geschäftsdatenanfrage 1.1 | 01.04.2013 | 30.09.2013 |
ORDERS / ORDRSP AHB Geschäftsdatenanfrage 1.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 23.10.2012 | 01.04.2013 | 30.09.2013 |
ORDERS / ORDRSP AHB Geschäftsdatenanfrage 1.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 13.12.2012 | 01.04.2013 | 30.09.2013 |
ORDERS / ORDRSP AHB Geschäftsdatenanfrage 1.1a | 01.10.2013 | 31.03.2014 |
ORDERS / ORDRSP AHB Geschäftsdatenanfrage 1.2 | 01.04.2014 | 30.09.2014 |
ORDERS / ORDRSP AHB Geschäftsdatenanfrage 1.2a | 01.10.2014 | 31.03.2015 |
ORDERS / ORDRSP AHB Geschäftsdatenanfrage 1.2b | 01.04.2015 | 30.09.2015 |
ORDERS / ORDRSP AHB Geschäftsdatenanfrage 1.3 | 01.10.2015 | 31.03.2016 |
ORDERS / ORDRSP AHB Geschäftsdatenanfrage 1.3a | 01.04.2016 | 30.09.2016 |
ORDERS / ORDRSP AHB Geschäftsdatenanfrage 1.3b | 01.10.2016 | 30.09.2017 |
ORDERS / ORDRSP AHB Geschäftsdatenanfrage 1.3b Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 17.06.2016 | 01.10.2016 | 31.03.2016 |
ORDERS / ORDRSP AHB Geschäftsdatenanfrage 1.4 | 01.10.2017 | 31.03.2019 |
ORDERS / ORDRSP AHB Geschäftsdatenanfrage 1.4 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.11.2017 | 01.10.2017 | 31.03.2019 |
ORDERS / ORDRSP AHB Geschäftsdatenanfrage 1.4a | 01.04.2019 | 30.11.2019 |
ORDERS / ORDRSP AHB MaBiS 2.0 | 01.12.2019 | 31.03.2020 |
ORDERS / ORDRSP AHB MaBiS 2.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.07.2019 | 01.12.2019 | 31.03.2020 |
ORDERS / ORDRSP AHB MaBiS 2.0b | 01.04.2021 | Offen |
QUOTES MIG 1.0 | 01.10.2011 | 31.03.2013 |
QUOTES MIG 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 02.04.2012 | 01.10.2011 | 31.03.2013 |
QUOTES MIG 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 14.05.2012 | 01.10.2011 | 31.03.2013 |
QUOTES MIG 1.0a | 01.04.2013 | 31.03.2014 |
QUOTES MIG 1.0a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.02.2013 | 15.02.2013 | 31.03.2014 |
QUOTES MIG 1.0c | 01.10.2014 | 31.03.2015 |
QUOTES MIG 1.0c Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 20.01.2015 | 20.01.2015 | 31.03.2015 |
QUOTES MIG 1.0d | 01.04.2015 | 31.03.2015 |
QUOTES MIG 1.0d Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 20.01.2015 | 01.04.2015 | 31.03.2016 |
QUOTES MIG 1.0e | 01.04.2016 | 30.09.2016 |
QUOTES MIG 1.0f | 01.10.2016 | 30.09.2017 |
QUOTES MIG 1.1 | 01.10.2017 | 30.11.2019 |
REQOTE / QUOTES / ORDERS / ORDRSP AHB 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 29.11.2019 | 01.12.2019 | 16.12.2019 |
REQOTE / QUOTES / ORDERS / ORDRSP AHB 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.07.2019 | 01.12.2019 | 01.10.2019 |
REQOTE / QUOTES / ORDERS / ORDRSP AHB 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 11.11.2019 | 01.12.2019 | 28.11.2019 |
REQOTE / QUOTES / ORDERS / ORDRSP AHB 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 02.10.2019 | 01.12.2019 | 10.11.2019 |
REQOTE / QUOTES / ORDERS / ORDRSP AHB 1.0b | 01.04.2021 | Offen |
REQOTE / QUOTES / ORDERS / ORDRSP AHB WiM 1.0 | 01.04.2011 | 31.03.2013 |
REQOTE / QUOTES / ORDERS / ORDRSP AHB WiM 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 02.04.2012 | 01.10.2011 | 31.03.2013 |
REQOTE / QUOTES / ORDERS / ORDRSP AHB WiM 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 28.09.2012 | 28.09.2012 | 31.03.2013 |
REQOTE / QUOTES / ORDERS / ORDRSP AHB WiM 1.1 | 01.04.2013 | 30.09.2013 |
REQOTE / QUOTES / ORDERS / ORDRSP AHB WiM 1.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 13.12.2012 | 01.04.2013 | 30.09.2013 |
REQOTE / QUOTES / ORDERS / ORDRSP AHB WiM 1.1a | 01.10.2013 | 31.03.2014 |
REQOTE / QUOTES / ORDERS / ORDRSP AHB WiM 1.2 | 01.04.2014 | 30.09.2014 |
REQOTE / QUOTES / ORDERS / ORDRSP AHB WiM 1.2 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 13.01.2014 | 01.04.2014 | 30.09.2014 |
REQOTE / QUOTES / ORDERS / ORDRSP AHB WiM 1.2a | 01.10.2014 | 31.03.2015 |
REQOTE / QUOTES / ORDERS / ORDRSP AHB WiM 1.2b | 01.04.2015 | 30.09.2015 |
REQOTE / QUOTES / ORDERS / ORDRSP AHB WiM 1.2c | 01.10.2015 | 31.03.2016 |
REQOTE / QUOTES / ORDERS / ORDRSP AHB WiM 1.2d | 01.04.2016 | 30.09.2017 |
REQOTE / QUOTES / ORDERS / ORDRSP AHB WiM 1.3 | 01.10.2017 | 31.03.2019 |
REQOTE / QUOTES / ORDERS / ORDRSP AHB WiM 1.3a | 01.04.2019 | 30.11.2019 |
REQOTE / QUOTES / ORDERS / ORDRSP AHB WiM 1.3 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 16.11.2018 | 01.10.2017 | 31.03.2019 |
REQOTE / QUOTES / ORDERS / ORDRSP AHB WiM 1.3a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 16.11.2018 | 01.04.2019 | 30.11.2019 |
REQOTE MIG 1.0 | 01.10.2011 | 30.09.2014 |
REQOTE MIG 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 02.04.2012 | 01.10.2011 | 30.09.2014 |
REQOTE MIG 1.1 | 01.10.2014 | 31.03.2015 |
REQOTE MIG 1.1a | 01.04.2015 | 30.09.2017 |
REQOTE MIG 1.1b | 01.10.2017 | 30.11.2019 |
REQOTE / QUOTES / ORDERS / ORDRSP AHB 1.0 | 01.12.2019 | 31.03.2020 |
REQOTE / QUOTES / ORDERS / ORDRSP AHB 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 17.12.2019 | 17.12.2019 | 31.03.2020 |
Bewegungsdaten
MSCONS MIG 2.1 | 01.10.2013 | 31.03.2013 |
MSCONS MIG 2.1a | 01.04.2009 | 30.09.2011 |
MSCONS MIG 2.1c | 01.10.2011 | 31.03.2012 |
MSCONS MIG 2.1d | 01.04.2012 | 30.09.2013 |
MSCONS MIG 2.2 | 01.04.2013 | 30.09.2013 |
MSCONS MIG 2.2a | 01.10.2013 | 31.03.2014 |
MSCONS MIG 2.2b | 01.04.2014 | 30.09.2014 |
MSCONS MIG 2.2c | 01.10.2014 | 31.03.2015 |
MSCONS MIG 2.2d | 01.04.2015 | 30.09.2015 |
MSCONS MIG 2.2e | 01.10.2015 | 31.03.2016 |
MSCONS MIG 2.2f | 01.04.2016 | 30.09.2016 |
MSCONS MIG 2.2g | 01.10.2016 | 30.09.2017 |
MSCONS MIG 2.2h | 01.10.2017 | 31.03.2019 |
MSCONS MIG 2.2i | 01.04.2019 | 30.11.2019 |
MSCONS MIG 2.2i Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 16.11.2018 | 01.04.2019 | 30.11.2019 |
MSCONS MIG 2.3 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.07.2019 | 01.12.2019 | 16.12.2019 |
MSCONS MIG 2.3a | 01.04.2021 | Offen |
MSCONS AHB 2.3a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 03.04.2020 | 03.04.2020 | 09.06.2020 |
MSCONS AHB 2.0c | 01.04.2007 | 30.09.2007 |
MSCONS AHB 2.0c | 01.10.2007 | 30.07.2008 |
MSCONS AHB 2.0d | 01.10.2007 | Offen |
MSCONS AHB 2.0d | 31.07.2008 | 31.03.2009 |
MSCONS AHB 2.1 | 01.10.2008 | 31.03.2009 |
MSCONS AHB 2.1a | 01.04.2009 | 31.03.2010 |
MSCONS AHB 2.1b | 01.04.2010 | 31.03.2011 |
MSCONS AHB 2.1c | 01.04.2011 | 30.09.2011 |
MSCONS AHB 2.1d | 01.10.2011 | 31.03.2012 |
MSCONS AHB 2.1e | 01.04.2012 | 31.03.2013 |
MSCONS AHB 2.1e Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.02.2012 | 01.04.2012 | 31.03.2013 |
MSCONS AHB 2.1e Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 28.09.2012 | 28.09.2012 | 31.03.2013 |
MSCONS AHB 2.2 | 01.04.2013 | 30.09.2013 |
MSCONS AHB 2.2 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 11.01.2013 | 01.04.2013 | 30.09.2013 |
MSCONS AHB 2.2a | 01.10.2013 | 31.03.2014 |
MSCONS AHB 2.2a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 19.09.2013 | 01.10.2013 | 31.03.2014 |
MSCONS AHB 2.2b | 01.04.2014 | 30.09.2014 |
MSCONS AHB 2.2b Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 29.11.2013 | 01.04.2014 | 30.09.2014 |
MSCONS AHB 2.2b Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 29.11.2013 | 01.04.2014 | 30.09.2014 |
MSCONS AHB 2.2b Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 27.02.2014 | 01.04.2014 | 30.09.2014 |
MSCONS AHB 2.2b Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 27.02.2014 | 01.04.2014 | Offen |
MSCONS AHB 2.2c | 01.10.2014 | 31.03.2015 |
MSCONS AHB 2.2d | 01.04.2015 | 30.09.2015 |
MSCONS AHB 2.2d Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 20.01.2015 | 01.04.2015 | 30.09.2015 |
MSCONS AHB 2.2d Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 30.01.2015 | 01.04.2015 | 30.09.2015 |
MSCONS AHB 2.2e | 01.10.2015 | 31.03.2016 |
MSCONS AHB 2.2e Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 22.05.2015 | 01.10.2015 | 31.03.2016 |
MSCONS AHB 2.2e Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 19.06.2015 | 01.10.2015 | 31.03.2016 |
MSCONS AHB 2.2e Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.09.2015 | 01.10.2015 | 31.03.2016 |
MSCONS AHB 2.2e Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.09.2015 | 01.10.2015 | 31.03.2016 |
MSCONS AHB 2.2f | 01.04.2016 | 30.09.2016 |
MSCONS AHB 2.2f Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 29.01.2016 | 01.04.2016 | 30.09.2016 |
MSCONS AHB 2.2g | 01.10.2016 | 30.09.2017 |
MSCONS AHB 2.2g Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 17.06.2016 | 01.10.2016 | 30.09.2017 |
MSCONS AHB 2.2g Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 04.07.2016 | 01.10.2016 | 30.09.2017 |
MSCONS AHB 2.2g Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 30.11.2016 | 01.10.2016 | 30.09.2017 |
MSCONS AHB 2.2h | 01.10.2017 | 31.03.2019 |
MSCONS AHB 2.2h Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 08.05.2017 | 01.10.2017 | 25.06.2017 |
MSCONS AHB 2.2h Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 26.06.2017 | 01.10.2017 | 25.03.2018 |
MSCONS AHB 2.2h Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 26.03.2018 | 01.10.2017 | 16.07.2018 |
MSCONS AHB 2.2h Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 17.07.2018 | 01.10.2017 | 09.01.2019 |
MSCONS AHB 2.2h Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 10.01.2019 | 10.01.2019 | 31.03.2019 |
MSCONS AHB 2.2i | 01.04.2019 | 30.11.2019 |
MSCONS AHB 2.2i Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 16.11.2018 | 01.04.2019 | 09.12.2018 |
MSCONS AHB 2.2i Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 10.12.2018 | 01.04.2019 | 09.01.2019 |
MSCONS AHB 2.2i Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 10.01.2019 | 01.04.2019 | 14.07.2019 |
MSCONS AHB 2.2i Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.07.2019 | 01.04.2019 | 30.11.2019 |
MSCONS AHB 2.3 | 01.12.2019 | 31.03.2020 |
MSCONS AHB 2.3 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.07.2019 | 01.12.2019 | 01.10.2019 |
MSCONS AHB 2.3 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 02.10.2019 | 01.12.2019 | 16.12.2019 |
MSCONS AHB 2.3 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 17.12.2019 | 17.12.2019 | 31.03.2020 |
MSCONS AHB 2.3a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 10.06.2020 | 10.06.2020 | 29.09.2020 |
MSCONS AHB 2.3b | 01.04.2021 | Offen |
MSCONS AHB 2.3b Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 10.06.2020 | 01.04.2021 | Offen |
Codelisten
Artikelnummernliste des BDEW 2.0 | 01.10.2008 | 31.03.2009 |
Artikelnummernliste des BDEW 3.0 | 01.04.2009 | 31.03.2010 |
Artikelnummernliste des BDEW 3.0a | 01.04.2010 | 30.09.2010 |
Artikelnummernliste des BDEW 4.0 | 01.10.2010 | 31.03.2011 |
Artikelnummernliste des BDEW 4.0a | 01.04.2011 | 30.09.2011 |
Artikelnummernliste des BDEW 4.1 | 01.10.2011 | 15.11.2011 |
Artikelnummernliste des BDEW 4.1a | 16.11.2011 | 30.09.2012 |
Artikelnummernliste des BDEW 4.1b | 01.10.2012 | 30.09.2012 |
Artikelnummernliste des BDEW 4.1b Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 23.10.2012 | 01.01.2013 | 30.09.2013 |
Artikelnummernliste des BDEW 4.1c | 01.10.2013 | 30.09.2015 |
Artikelnummernliste des BDEW 4.1d | 01.10.2015 | 30.09.2016 |
Artikelnummernliste des BDEW 4.1e | 01.10.2016 | 30.11.2016 |
Artikelnummernliste des BDEW 4.1e Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 17.06.2016 | 01.10.2016 | 29.11.2016 |
Artikelnummernliste des BDEW 4.1e Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 30.11.2016 | 30.11.2016 | 30.09.2017 |
Artikelnummernliste des BDEW 4.1f | 01.10.2017 | 30.11.2019 |
Artikelnummernliste des BDEW 4.1f Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 16.11.2018 | 01.10.2017 | 30.11.2019 |
Artikelnummernliste des BDEW 4.1g | 01.12.2019 | 30.09.2020 |
Codeliste der OBIS-Kennzahlen 2.0 | 01.04.2009 | 30.09.2011 |
Codeliste der OBIS-Kennzahlen 2.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 02.04.2012 | 01.10.2011 | 30.09.2012 |
Codeliste der OBIS-Kennzahlen 2.2 | 01.10.2012 | 30.09.2013 |
Codeliste der OBIS-Kennzahlen 2.2a | 01.10.2013 | 31.03.2013 |
Codeliste der OBIS-Kennzahlen 2.2b | 01.04.2013 | 30.09.2015 |
Codeliste der OBIS-Kennzahlen 2.2b Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 29.11.2013 | 01.04.2014 | 30.09.2015 |
Codeliste der OBIS-Kennzahlen 2.2b Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 12.06.2014 | 01.10.2014 | 30.09.2015 |
Codeliste der OBIS-Kennzahlen 2.2c | 01.10.2015 | 31.03.2016 |
Codeliste der OBIS-Kennzahlen 2.2c Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 19.06.2015 | 01.10.2015 | 31.03.2016 |
Codeliste der OBIS-Kennzahlen 2.2d | 01.04.2016 | Offen |
Codeliste der OBIS-Kennzahlen 2.2e | 01.10.2016 | 30.09.2017 |
Codeliste der OBIS-Kennzahlen 2.2f | 01.10.2017 | 31.03.2019 |
Codeliste der OBIS-Kennzahlen 2.2f Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 09.06.2017 | 01.10.2017 | Offen |
Codeliste der OBIS-Kennzahlen 2.2f Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 09.06.2017 | 01.10.2017 | 31.03.2019 |
Codeliste der OBIS-Kennzahlen 2.2g | 01.04.2019 | 30.11.2019 |
Codeliste der OBIS-Kennzahlen 2.2g Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 10.12.2018 | 01.04.2019 | 30.11.2019 |
Codeliste der OBIS-Kennzahlen 2.2h Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.07.2019 | 01.12.2019 | 01.10.2019 |
Codeliste der OBIS-Kennzahlen 2.2h Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 02.10.2019 | 01.12.2019 | 10.11.2019 |
Codeliste der OBIS-Kennzahlen 2.2h Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 11.11.2019 | 01.12.2019 | 16.12.2019 |
Codeliste der Standardlastprofile nach TU München-Verfahren 1.0a | 01.04.2013 | 31.03.2013 |
Codeliste der Standardlastprofile nach TU München-Verfahren 1.0b | 01.04.2014 | 30.09.2015 |
Codeliste der Statuszusatzinformation 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 02.08.2013 | 01.10.2013 | 30.09.2015 |
Codeliste der Statuszusatzinformation 1.0a | 01.10.2015 | 30.09.2017 |
Codeliste der Statuszusatzinformation 1.0b | 01.10.2017 | 31.03.2019 |
Codeliste der Statuszusatzinformation 1.0c | 01.04.2019 | 30.11.2019 |
Codeliste der Statuszusatzinformation 1.0c Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 25.02.2019 | 01.04.2019 | 30.11.2019 |
Codeliste der Temperaturanbieter 1.0 | 01.04.2009 | 23.04.2009 |
Codeliste der Temperaturanbieter 1.0a | 24.04.2009 | 31.03.2010 |
Codeliste der Temperaturanbieter 1.0b | 01.04.2010 | 30.09.2011 |
Codeliste der Temperaturanbieter 1.0c | 01.10.2011 | 14.09.2015 |
Codeliste der Temperaturanbieter 1.0d | 15.09.2015 | 29.11.2016 |
Codeliste der Temperaturanbieter 1.0e | 30.11.2016 | Offen |
Codeliste der Temperaturanbieter 1.0e | 01.12.2016 | 06.12.2018 |
Codeliste der Temperaturanbieter 1.0f | 07.12.2018 | 05.05.2019 |
Codeliste der Temperaturanbieter 1.0g | 06.05.2019 | 02.04.2020 |
Codeliste der Zeitreihentypen 1.0 | 01.04.2011 | 31.03.2012 |
Codeliste der Zeitreihentypen 1.1 | 01.04.2012 | 31.03.2013 |
Codeliste der Zeitreihentypen 1.1a | 01.04.2013 | 30.09.2017 |
Codeliste der Zeitreihentypen 1.1a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 13.12.2012 | 01.04.2013 | 31.03.2014 |
Codeliste der Zeitreihentypen 1.1a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 27.02.2014 | 01.04.2014 | 30.09.2017 |
Codeliste der Zeitreihentypen 1.1b | 01.10.2017 | 30.11.2019 |
Datenaustausch zu Behörden
Herkunftsnachweisregister AHB 1.0 | 01.10.2012 | 31.03.2013 |
Herkunftsnachweisregister AHB 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 14.05.2012 | 01.10.2012 | 30.09.2012 |
Herkunftsnachweisregister AHB 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 30.07.2012 | 01.10.2012 | 31.03.2013 |
Herkunftsnachweisregister AHB 2.0 | 01.04.2013 | 30.09.2013 |
Herkunftsnachweisregister AHB 2.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 28.02.2013 | 01.04.2013 | 31.03.2014 |
Herkunftsnachweisregister AHB 2.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 13.12.2013 | 01.04.2013 | 31.03.2013 |
Herkunftsnachweisregister AHB 2.0a | 01.10.2013 | 31.03.2014 |
Herkunftsnachweisregister AHB 2.1 | 01.04.2014 | 30.09.2014 |
Herkunftsnachweisregister AHB 2.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 13.01.2014 | 01.04.2014 | 31.03.2014 |
Herkunftsnachweisregister AHB 2.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 26.03.2014 | 01.04.2014 | 30.09.2014 |
Herkunftsnachweisregister AHB 2.1a | 01.10.2014 | 31.03.2015 |
Herkunftsnachweisregister AHB 2.1a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 28.05.2014 | 01.10.2014 | 31.03.2011 |
Herkunftsnachweisregister AHB 2.1b | 01.04.2015 | 30.09.2015 |
Herkunftsnachweisregister AHB 2.1c | 01.10.2015 | 31.03.2016 |
Herkunftsnachweisregister AHB 2.1d | 01.04.2016 | 30.09.2016 |
Herkunftsnachweisregister AHB 2.1e | 01.10.2016 | 30.09.2017 |
Herkunftsnachweisregister AHB 2.1f | 01.10.2017 | 31.03.2019 |
Herkunftsnachweisregister AHB 2.1f Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.11.2017 | 01.10.2017 | 31.03.2019 |
Herkunftsnachweisregister AHB 2.1g | 01.04.2019 | 30.11.2019 |
Herkunftsnachweisregister AHB 2.2 | 01.12.2019 | 31.03.2020 |
Herkunftsnachweisregister AHB 2.2 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.07.2019 | 01.12.2019 | 10.11.2019 |
Herkunftsnachweisregister AHB 2.2 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 11.11.2019 | 01.12.2019 | 16.12.2019 |
Herkunftsnachweisregister AHB 2.2 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 17.12.2019 | 17.12.2019 | 31.03.2020 |
Herkunftsnachweisregister AHB 2.2b | 01.04.2021 | Offen |
Formatübergreifende Dokumente
Allgemeine Festlegungen 1.0a | 01.04.2010 | 30.09.2010 |
Allgemeine Festlegungen 1.0b | 01.10.2010 | 31.03.2011 |
Allgemeine Festlegungen 2.0 | 01.04.2011 | 30.09.2011 |
Allgemeine Festlegungen 3.0 | 01.10.2011 | 31.03.2012 |
Allgemeine Festlegungen 3.1 | 01.04.2012 | 31.03.2013 |
Allgemeine Festlegungen 3.2 | 01.04.2013 | 30.09.2013 |
Allgemeine Festlegungen 3.2 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 14.12.2012 | 01.04.2013 | 31.03.2013 |
Allgemeine Festlegungen 3.3 | 01.10.2013 | 31.03.2014 |
Allgemeine Festlegungen 3.3 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 02.08.2018 | 01.10.2013 | 31.03.2014 |
Allgemeine Festlegungen 3.3a | 01.04.2014 | 30.09.2014 |
Allgemeine Festlegungen 3.3a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 26.03.2014 | 01.04.2014 | 30.09.2014 |
Allgemeine Festlegungen 4.0 | 01.10.2014 | 31.03.2015 |
Allgemeine Festlegungen 4.1 | 01.04.2015 | 30.09.2015 |
Allgemeine Festlegungen 4.1a | 01.10.2015 | 31.03.2016 |
Allgemeine Festlegungen 4.1a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 22.05.2015 | 01.10.2015 | 24.09.2015 |
Allgemeine Festlegungen 4.1a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 25.09.2015 | 01.10.2015 | 04.11.2015 |
Allgemeine Festlegungen 4.1a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 05.11.2015 | 05.11.2015 | 31.03.2016 |
Allgemeine Festlegungen 4.2 | 01.04.2016 | 30.09.2016 |
Allgemeine Festlegungen 4.2 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 05.11.2015 | 01.04.2016 | 14.01.2016 |
Allgemeine Festlegungen 4.2 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.01.2016 | 01.04.2016 | 30.09.2016 |
Allgemeine Festlegungen 4.2a | 01.10.2016 | 31.03.2017 |
Allgemeine Festlegungen 4.3 | 01.04.2017 | 30.09.2017 |
Allgemeine Festlegungen 4.4 | 01.10.2017 | 31.03.2019 |
Allgemeine Festlegungen 4.4 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 26.06.2017 | 01.10.2017 | 31.08.2017 |
Allgemeine Festlegungen 4.4 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 01.09.2017 | 01.10.2017 | 24.09.2017 |
Allgemeine Festlegungen 4.4 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 25.09.2017 | 01.10.2017 | 16.07.2018 |
Allgemeine Festlegungen 4.4 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 17.07.2018 | 01.10.2017 | 31.03.2019 |
Allgemeine Festlegungen 4.5 | 01.04.2019 | 30.11.2019 |
Anwendungsübersicht der Prüfidentifikatoren 1.0 | 01.10.2017 | 31.03.2019 |
Anwendungsübersicht der Prüfidentifikatoren 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 08.05.2017 | 01.10.2017 | Offen |
Anwendungsübersicht der Prüfidentifikatoren 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 26.03.2018 | 01.10.2017 | 31.03.2019 |
Anwendungsübersicht der Prüfidentifikatoren 1.0a | 01.04.2019 | 30.11.2019 |
Anwendungsübersicht der Prüfidentifikatoren 1.0a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 10.01.2019 | 01.04.2019 | 30.11.2019 |
Anwendungsübersicht der Prüfidentifikatoren 1.1 | 01.12.2019 | 31.03.2020 |
Anwendungsübersicht der Prüfidentifikatoren 1.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.07.2019 | 01.12.2019 | 01.10.2019 |
Anwendungsübersicht der Prüfidentifikatoren 1.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 02.10.2019 | 01.12.2019 | 10.11.2019 |
Anwendungsübersicht der Prüfidentifikatoren 1.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 11.11.2019 | 01.12.2019 | 16.12.2019 |
Anwendungsübersicht der Prüfidentifikatoren 1.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 17.12.2019 | 17.12.2019 | 31.03.2020 |
Anwendungsübersicht der Prüfidentifikatoren 1.2 | 01.04.2020 | 30.09.2020 |
Anwendungsübersicht der Prüfidentifikatoren 1.2 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 03.04.2020 | 03.04.2020 | 09.06.2020 |
Anwendungsübersicht der Prüfidentifikatoren 1.2 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 10.06.2020 | 10.06.2020 | 30.09.2020 |
Anwendungsübersicht der Prüfidentifikatoren 1.3 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 10.06.2020 | 01.04.2021 | 30.06.2020 |
EDI@Energy Anwendungshilfe Einführungsszenario: Übermittlung von Daten an den ÜNB 1.0 | 01.04.2020 | 21.04.2020 |
EDI@Energy Anwendungshilfe Einführungsszenario: Übermittlung von Daten an den ÜNB 1.0 | 01.04.2020 | 21.04.2020 |
EDI@Energy Anwendungshilfe Einführungsszenario: Übermittlung von Daten an den ÜNB 1.0 | 01.04.2020 | 21.04.2020 |
EDI@Energy Anwendungshilfe zu den Datenformaten des Interimsmodells 1.0 | 01.10.2017 | Offen |
EDI@Energy Anwendungshilfe zu den Datenformaten des Interimsmodells 1.0 | 01.10.2017 | Offen |
EDI@Energy Anwendungshilfe zu den Datenformaten des Interimsmodells 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 20.07.2017 | 01.10.2017 | Offen |
EDI@Energy Anwendungshilfe zu den Datenformaten des Interimsmodells 1.1 | 15.08.2017 | Offen |
EDI@Energy Anwendungshilfe zu den Datenformaten des Interimsmodells 1.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 01.09.2017 | 01.10.2017 | Offen |
EDI@Energy Anwendungshilfe zu den Datenformaten des Interimsmodells 1.2 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 26.03.2018 | 01.10.2017 | 29.07.2018 |
EDI@Energy Anwendungshilfe zu den Datenformaten des Interimsmodells 1.3, Stand: 30.07.2018 | 01.10.2017 | 04.10.2018 |
EDI@Energy Anwendungshilfe zu den Datenformaten des Interimsmodells 1.3 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 05.10.2018 | 01.10.2017 | 15.11.2018 |
EDI@Energy Anwendungshilfe zu den Datenformaten des Interimsmodells 1.3 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 16.11.2018 | 01.10.2017 | 24.02.2019 |
EDI@Energy Anwendungshilfe zu den Datenformaten des Interimsmodells 1.3 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 25.02.2019 | 01.10.2017 | 30.11.2019 |
EDI@Energy Anwendungshilfe zu den Datenformaten der Marktkommunikation 2020 1.0 | 01.12.2019 | 17.02.2020 |
EDI@Energy Anwendungshilfe zu den Datenformaten der Marktkommunikation 2020 14 - 006 | 01.10.2017 | 07.11.2018 |
EDI@Energy Anwendungshilfe zu den Datenformaten der Marktkommunikation 2020 14 - 007 | 08.11.2018 | Offen |
EDI@Energy Anwendungshilfe zu den Datenformaten der Marktkommunikation 2020 14 - 011 | 19.12.2018 | 31.03.2019 |
EDI@Energy Anwendungshilfe zu den Datenformaten der Marktkommunikation 2020 Der Service wird ab dem 1.8.2019 eingestellt. | 01.04.2019 | 31.07.2019 |
EDI@Energy Anwendungshilfe zu den Datenformaten der Marktkommunikation 2020 1.1 | 18.02.2020 | 06.05.2020 |
EDI@Energy Anwendungshilfe zu den Datenformaten der Marktkommunikation 2020 1.2 | 07.05.2020 | 27.05.2020 |
Entscheidungsbaum-Diagramme 1.0 | 01.10.2017 | Offen |
Entscheidungsbaum-Diagramme 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.11.2017 | 01.10.2017 | 15.11.2018 |
Entscheidungsbaum-Diagramme 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 16.11.2018 | 01.10.2017 | 29.01.2019 |
Entscheidungsbaum-Diagramme 2.0 | 01.12.2019 | 31.03.2020 |
Entscheidungsbaum-Diagramme 2.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.07.2019 | 01.12.2019 | 10.11.2019 |
Entscheidungsbaum-Diagramme 2.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 11.11.2019 | 01.12.2019 | 31.03.2020 |
Entscheidungsbaum-Diagramme 2.2 | 01.04.2021 | Offen |
Gruppierungen der EDI@Energy Dokumente 1.0 | 09.04.2018 | 30.11.2019 |
Regelungen zum Übertragungsweg 1.1 | 01.06.2017 | 31.03.2019 |
Regelungen zum Übertragungsweg 1.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 12.12.2017 | 01.06.2017 | 31.03.2019 |
Regelungen zum Übertragungsweg 1.2 | 01.04.2019 | 30.09.2020 |
Regelungen zum Übertragungsweg 1.2 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 16.11.2018 | 01.04.2019 | 28.03.2019 |
Regelungen zum Übertragungsweg 1.2 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 29.03.2019 | 01.04.2019 | 30.09.2020 |
KWEP 1
Acknowledgement 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 11.11.2014 | 11.11.2014 | 31.03.2015 |
Acknowledgement 1.0a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 03.03.2015 | 01.04.2015 | Offen |
Acknowledgement 1.0a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 14.11.2014 | 01.04.2015 | Offen |
Unavailability Market 1.0 | 01.10.2014 | 31.03.2015 |
Unavailability Market 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 03.03.2015 | 01.04.2015 | Offen |
Rechnungsstellung
INVOIC MIG 2.1 | 01.08.2008 | 31.03.2009 |
INVOIC MIG 2.2 | 01.04.2009 | 31.03.2010 |
INVOIC MIG 2.3 | 01.04.2010 | 30.09.2010 |
INVOIC MIG 2.3a | 01.10.2010 | 31.03.2011 |
INVOIC MIG 2.4 | 01.04.2011 | 30.09.2011 |
INVOIC MIG 2.5 | 01.10.2011 | 30.09.2013 |
INVOIC MIG 2.5a | 01.10.2013 | 30.09.2014 |
INVOIC MIG 2.5a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 01.07.2013 | 01.10.2013 | 30.09.2014 |
INVOIC MIG 2.6 | 01.10.2014 | 31.03.2015 |
INVOIC MIG 2.6a | 01.04.2015 | 30.09.2015 |
INVOIC MIG 2.6b | 01.10.2015 | 31.03.2016 |
INVOIC MIG 2.6c | 01.04.2016 | 30.09.2016 |
INVOIC MIG 2.6d | 01.10.2016 | 30.09.2017 |
INVOIC MIG 2.6e | 01.10.2017 | Offen |
INVOIC MIG 2.6e | 01.10.2017 | 30.11.2019 |
INVOIC MIG 2.6e Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 31.07.2017 | 01.10.2017 | 30.11.2019 |
INVOIC MIG 2.6f | 01.12.2019 | 30.09.2020 |
INVOIC / REMADV AHB 1.0 | 03.05.2006 | 10.12.2007 |
INVOIC / REMADV AHB 1.0a | 11.12.2007 | 30.09.2008 |
INVOIC / REMADV AHB 1.1 | 01.10.2008 | 31.03.2009 |
INVOIC / REMADV AHB 1.2 | 01.04.2009 | 31.03.2010 |
INVOIC / REMADV AHB 1.3 | 01.04.2010 | 30.09.2010 |
INVOIC / REMADV AHB 1.3a | 01.10.2010 | 31.03.2011 |
INVOIC / REMADV AHB 1.4 | 01.04.2011 | 31.03.2011 |
INVOIC / REMADV AHB 1.5 | 01.04.2011 | 31.03.2013 |
INVOIC / REMADV AHB 1.5 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 02.04.2012 | 01.10.2011 | 31.03.2013 |
INVOIC / REMADV AHB 1.6 | 01.04.2013 | 30.09.2013 |
INVOIC / REMADV AHB 2.0 | 01.10.2013 | 30.09.2014 |
INVOIC / REMADV AHB 2.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 01.07.2013 | 01.10.2013 | 30.09.2014 |
INVOIC / REMADV AHB 2.1 | 01.10.2014 | 31.03.2015 |
INVOIC / REMADV AHB 2.2 | 01.04.2015 | 30.09.2015 |
INVOIC / REMADV AHB 2.3 | 01.10.2015 | 30.04.2016 |
INVOIC / REMADV AHB 2.3 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 22.05.2015 | 01.10.2015 | 30.04.2016 |
INVOIC / REMADV AHB 2.3a | 01.05.2016 | 30.09.2016 |
INVOIC / REMADV AHB 2.3a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 05.11.2015 | 01.04.2016 | 30.09.2016 |
INVOIC / REMADV AHB 2.3b | 01.10.2016 | 30.09.2016 |
INVOIC / REMADV AHB 2.3c | 01.10.2017 | Offen |
INVOIC / REMADV AHB 2.3c | 01.10.2017 | 30.11.2019 |
INVOIC / REMADV AHB 2.3c Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 29.01.2018 | 01.10.2017 | 30.11.2019 |
INVOIC / REMADV AHB 2.3d | 01.12.2019 | 30.09.2020 |
INVOIC / REMADV AHB 2.3d Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.07.2019 | 01.12.2019 | 01.10.2019 |
INVOIC / REMADV AHB 2.3d Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 02.10.2019 | 01.12.2019 | 02.04.2020 |
INVOIC / REMADV AHB 2.3d Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 03.04.2020 | 03.04.2020 | 30.09.2020 |
PRICAT MIG 1.0 | 01.04.2011 | 31.03.2016 |
PRICAT MIG 1.0 | 01.04.2011 | 31.03.2016 |
PRICAT MIG 1.0a | 01.04.2016 | 30.09.2017 |
PRICAT MIG 1.1 | 01.10.2017 | 30.11.2019 |
PRICAT MIG 1.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 25.09.2017 | 01.10.2017 | 30.11.2019 |
PRICAT AHB 1.0 | 01.10.2017 | 30.11.2019 |
PRICAT AHB 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 25.09.2017 | 01.10.2017 | 30.11.2019 |
REMADV MIG 2.0 | 03.05.2006 | 03.12.2007 |
REMADV MIG 2.0a | 04.12.2007 | 31.07.2008 |
REMADV MIG 2.1 | 01.08.2008 | 31.03.2009 |
REMADV MIG 2.2 | 01.04.2009 | 31.03.2010 |
REMADV MIG 2.3 | 01.04.2010 | 30.09.2010 |
REMADV MIG 2.3a | 01.10.2010 | 30.09.2011 |
REMADV MIG 2.4 | 01.10.2011 | 31.03.2013 |
REMADV MIG 2.5 | 01.04.2013 | 31.03.2014 |
REMADV MIG 2.5a | 01.04.2014 | 30.09.2014 |
REMADV MIG 2.6 | 01.10.2014 | 31.03.2015 |
REMADV MIG 2.7 | 01.04.2015 | 30.09.2015 |
REMADV MIG 2.7a | 01.10.2015 | 31.03.2016 |
REMADV MIG 2.7b | 01.04.2016 | 30.09.2017 |
REMADV MIG 2.7c | 01.10.2017 | 30.11.2019 |
Servicenachrichten
APERAK MIG 2.0 | 01.04.2008 | 31.07.2008 |
APERAK MIG 2.0b | 01.04.2009 | 31.03.2010 |
APERAK MIG 2.0c | 01.04.2010 | 30.09.2010 |
APERAK MIG 2.0d | 01.10.2010 | 31.03.2011 |
APERAK MIG 2.0e | 01.04.2011 | 30.09.2011 |
APERAK MIG 2.0f | 01.10.2011 | 31.03.2012 |
APERAK MIG 2.0g | 01.04.2012 | 31.03.2013 |
APERAK MIG 2.1 | 01.04.2013 | 30.09.2014 |
APERAK MIG 2.1a | 01.10.2014 | 30.09.2017 |
APERAK MIG 2.1b | 01.10.2017 | 31.03.2019 |
APERAK MIG 2.1c | 01.04.2019 | 30.11.2019 |
APERAK MIG 2.1e | 01.04.2021 | Offen |
CONTRL MIG 1.0 | 01.06.2008 | Offen |
CONTRL MIG 1.3 | 31.07.2008 | 31.07.2008 |
CONTRL MIG 1.3 | 25.04.2007 | 30.09.2008 |
CONTRL MIG 1.3a | 01.10.2008 | 31.03.2009 |
CONTRL MIG 1.3a | 01.08.2008 | 31.03.2009 |
CONTRL MIG 1.3b | 01.04.2009 | 30.09.2010 |
CONTRL MIG 1.3b | 01.04.2009 | 30.09.2010 |
CONTRL MIG 1.3c | 01.10.2010 | 31.03.2011 |
CONTRL MIG 1.3c | 01.10.2010 | 31.03.2011 |
CONTRL MIG 1.3d | 01.04.2011 | 30.09.2014 |
CONTRL MIG 2.0 | 01.10.2014 | 30.11.2019 |
CONTRL MIG 2.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 30.11.2016 | 30.11.2016 | 30.11.2019 |
CONTRL MIG 2.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 30.11.2016 | 30.11.2016 | Offen |
APERAK / CONTRL AHB 2.0 | 01.10.2008 | 31.03.2009 |
APERAK / CONTRL AHB 2.0a | 01.04.2009 | 31.03.2010 |
APERAK / CONTRL AHB 2.0b | 01.04.2010 | 30.09.2010 |
APERAK / CONTRL AHB 2.0c | 01.10.2010 | 31.03.2011 |
APERAK / CONTRL AHB 2.0d | 01.04.2011 | 30.09.2011 |
APERAK / CONTRL AHB 2.0d | 01.10.2011 | 31.03.2012 |
APERAK / CONTRL AHB 2.0e | 01.10.2011 | 31.03.2012 |
APERAK / CONTRL AHB 2.0f | 01.04.2012 | 15.11.2011 |
APERAK / CONTRL AHB 2.3e | 01.04.2019 | 30.11.2019 |
APERAK / CONTRL AHB 2.3d | 01.10.2017 | 31.03.2019 |
APERAK / CONTRL AHB 2.0a | 01.08.2008 | 31.03.2009 |
APERAK / CONTRL AHB 2.0a | 01.08.2008 | 18.05.2008 |
APERAK / CONTRL AHB 2.0g | 01.04.2012 | 30.09.2012 |
APERAK / CONTRL AHB 2.0h | 01.10.2012 | 31.03.2013 |
APERAK / CONTRL AHB 2.1 | 01.04.2013 | 30.09.2013 |
APERAK / CONTRL AHB 2.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 13.12.2012 | 01.04.2013 | Offen |
APERAK / CONTRL AHB 2.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 25.01.2013 | 01.04.2013 | Offen |
APERAK / CONTRL AHB 2.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 28.02.2013 | 01.04.2013 | 30.09.2013 |
APERAK / CONTRL AHB 2.1a | 01.10.2013 | 31.03.2014 |
APERAK / CONTRL AHB 2.2 | 01.04.2014 | 30.09.2014 |
APERAK / CONTRL AHB 2.2 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 26.03.2014 | 01.04.2014 | 31.03.2013 |
APERAK / CONTRL AHB 2.3 | 01.10.2014 | 31.03.2015 |
APERAK / CONTRL AHB 2.3a | 01.04.2015 | 30.09.2015 |
APERAK / CONTRL AHB 2.3 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 28.05.2014 | 01.10.2014 | Offen |
APERAK / CONTRL AHB 2.3 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 25.07.2014 | 01.10.2014 | 24.07.2017 |
APERAK / CONTRL AHB 2.3b | 01.10.2015 | 31.03.2016 |
APERAK / CONTRL AHB 2.3c | 01.04.2016 | 30.09.2017 |
APERAK / CONTRL AHB 2.3c Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 17.06.2016 | 17.06.2016 | 30.09.2017 |
APERAK / CONTRL AHB 2.3c Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 30.11.2016 | 30.11.2016 | Offen |
APERAK / CONTRL AHB 2.3c Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 30.11.2016 | 30.11.2016 | Offen |
APERAK / CONTRL AHB 2.3d | 01.10.2017 | Offen |
APERAK / CONTRL AHB 2.3f Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 02.10.2019 | 01.12.2019 | 09.06.2020 |
APERAK / CONTRL AHB 2.3g | 01.04.2021 | Offen |
APERAK / CONTRL AHB 2.3g Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 10.06.2020 | 01.04.2021 | Offen |
Stammdaten
UTILTS AHB 1.0a | 01.04.2021 | Offen |
UTILMD MIG 4.0 | 24.01.2007 | 31.03.2008 |
UTILMD MIG 4.0a | 01.04.2008 | 01.04.2008 |
UTILMD MIG 4.1a | 01.08.2008 | 31.03.2009 |
UTILMD MIG 4.1a | 01.08.2008 | 31.03.2009 |
UTILMD MIG 4.2 | 01.04.2009 | 31.03.2010 |
UTILMD MIG 4.2a | 01.04.2010 | 30.09.2010 |
UTILMD MIG 4.2b | 01.10.2010 | 31.03.2011 |
UTILMD MIG 4.3 | 01.04.2011 | 30.09.2011 |
UTILMD MIG 4.4 | 01.10.2011 | 31.03.2012 |
UTILMD MIG 4.4a | 01.04.2012 | 30.09.2012 |
UTILMD MIG 4.4a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.02.2012 | 01.04.2012 | 20.03.2012 |
UTILMD MIG 4.4a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 21.03.2012 | 01.04.2012 | 30.09.2012 |
UTILMD MIG 4.5 | 01.10.2012 | 31.03.2013 |
UTILMD MIG 4.5 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 29.06.2012 | 01.10.2012 | 31.03.2013 |
UTILMD MIG 5.0 | 01.04.2013 | 30.09.2013 |
UTILMD MIG 5.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 13.12.2012 | 01.04.2013 | 24.01.2013 |
UTILMD MIG 5.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 25.01.2013 | 01.04.2013 | 30.01.2013 |
UTILMD MIG 5.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 23.05.2013 | 23.05.2013 | 30.09.2013 |
UTILMD MIG 5.1 | 01.10.2013 | 31.03.2014 |
UTILMD MIG 5.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 23.05.2013 | 01.10.2013 | 31.03.2014 |
UTILMD MIG 5.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 02.08.2013 | 01.10.2013 | 01.09.2013 |
UTILMD MIG 5.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 02.09.2013 | 01.10.2013 | 22.05.2013 |
UTILMD MIG 5.1a | 01.04.2014 | 30.09.2014 |
UTILMD MIG 5.1a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 13.01.2014 | 01.04.2014 | 25.03.2014 |
UTILMD MIG 5.1a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 26.03.2014 | 01.04.2014 | 27.05.2014 |
UTILMD MIG 5.1a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 28.05.2014 | 28.05.2014 | 30.09.2014 |
UTILMD MIG 5.1b | 01.10.2014 | 31.03.2015 |
UTILMD MIG 5.1b Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 28.05.2014 | 01.10.2014 | 31.03.2015 |
UTILMD MIG 5.1c | 01.04.2015 | 30.09.2015 |
UTILMD MIG 5.1c Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 03.03.2015 | 01.04.2015 | 21.05.2015 |
UTILMD MIG 5.1c Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 22.05.2015 | 22.05.2015 | 30.09.2015 |
UTILMD MIG 5.1d | 01.10.2015 | 31.03.2016 |
UTILMD MIG 5.1d Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 22.05.2015 | 01.10.2015 | 31.03.2016 |
UTILMD MIG 5.1e | 01.04.2016 | 30.09.2016 |
UTILMD MIG 5.1e Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.01.2016 | 01.04.2016 | 30.09.2016 |
UTILMD MIG 5.1f | 01.10.2016 | 30.09.2017 |
UTILMD MIG 5.1g | 01.10.2017 | 31.03.2019 |
UTILMD MIG 5.1g Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 26.03.2018 | 01.10.2017 | 16.07.2018 |
UTILMD MIG 5.1g Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 17.07.2018 | 01.10.2017 | 31.03.2019 |
UTILMD MIG 5.1h | 01.04.2019 | 30.11.2019 |
UTILMD MIG 5.2 | 01.12.2019 | 31.03.2020 |
UTILMD MIG 5.2 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.07.2019 | 01.12.2019 | 01.10.2019 |
UTILMD MIG 5.2 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 02.10.2019 | 01.12.2019 | 10.11.2019 |
UTILMD MIG 5.2 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 11.11.2019 | 01.12.2019 | 29.01.2020 |
UTILMD MIG 5.2 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 30.01.2020 | 30.01.2020 | 31.03.2020 |
UTILMD AHB Einspeiser 1.0 | 01.10.2013 | 31.03.2014 |
UTILMD AHB Einspeiser 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 23.05.2013 | 01.10.2013 | 31.03.2014 |
UTILMD AHB Einspeiser 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 19.09.2013 | 01.10.2013 | 31.03.2014 |
UTILMD AHB Einspeiser 2.0 | 01.04.2014 | 30.09.2014 |
UTILMD AHB Einspeiser 2.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 29.11.2013 | 01.04.2014 | 30.09.2014 |
UTILMD AHB Einspeiser 2.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 13.01.2014 | 01.04.2014 | 30.09.2014 |
UTILMD AHB Einspeiser 2.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 26.03.2014 | 01.04.2014 | 30.09.2014 |
UTILMD AHB Einspeiser 2.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 28.05.2014 | 28.05.2014 | 30.09.2014 |
UTILMD AHB Einspeiser 2.0a | 01.10.2014 | 31.03.2015 |
UTILMD AHB Einspeiser 2.0a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 28.05.2014 | 01.10.2014 | 31.03.2015 |
UTILMD AHB Einspeiser 2.0b | 01.04.2015 | 30.09.2015 |
UTILMD AHB Einspeiser 2.0c | 01.10.2015 | 31.03.2016 |
UTILMD AHB Einspeiser 2.0c Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.09.2015 | 01.10.2015 | 31.03.2016 |
UTILMD AHB Einspeiser 2.0d | 01.04.2016 | 30.09.2016 |
UTILMD AHB Einspeiser 2.0e | 01.10.2016 | 30.09.2017 |
UTILMD AHB Einspeiser 2.0f | 01.10.2017 | 31.03.2019 |
UTILMD AHB Einspeiser 2.0f Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.11.2017 | 01.10.2017 | 16.07.2018 |
UTILMD AHB Einspeiser 2.0f Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 17.07.2018 | 01.10.2017 | 31.03.2019 |
UTILMD AHB Einspeiser 2.0g | 01.04.2019 | 30.11.2019 |
UTILMD AHB Einspeiser 2.1 | 01.12.2019 | 31.03.2020 |
UTILMD AHB Einspeiser 2.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.07.2019 | 01.12.2019 | 01.10.2019 |
UTILMD AHB Einspeiser 2.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 02.10.2019 | 01.12.2019 | 10.11.2019 |
UTILMD AHB Einspeiser 2.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 11.11.2019 | 01.12.2019 | 16.12.2019 |
UTILMD AHB Einspeiser 2.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 17.12.2019 | 17.12.2019 | 31.03.2020 |
UTILMD AHB GPKE / GeLi Gas 4.2 | 01.04.2009 | 31.03.2010 |
UTILMD AHB GPKE / GeLi Gas 4.2a | 01.04.2010 | 30.09.2010 |
UTILMD AHB GPKE / GeLi Gas 4.2b | 01.10.2010 | 31.03.2011 |
UTILMD AHB GPKE / GeLi Gas 4.3 | 01.04.2011 | 31.03.2012 |
UTILMD AHB GPKE / GeLi Gas 4.4 | 01.04.2012 | 30.09.2011 |
UTILMD AHB GPKE / GeLi Gas 4.4a | 01.10.2011 | 30.09.2012 |
UTILMD AHB GPKE / GeLi Gas 4.4a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.02.2012 | 01.04.2012 | 30.09.2012 |
UTILMD AHB GPKE / GeLi Gas 4.4a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 21.03.2012 | 01.04.2012 | 30.09.2012 |
UTILMD AHB GPKE / GeLi Gas 4.5 | 01.10.2012 | 31.03.2013 |
UTILMD AHB GPKE / GeLi Gas 4.5 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 29.06.2012 | 01.10.2012 | 31.03.2013 |
UTILMD AHB GPKE / GeLi Gas 5.0 | 01.04.2013 | 30.09.2013 |
UTILMD AHB GPKE / GeLi Gas 5.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 23.10.2012 | 01.04.2013 | 30.09.2013 |
UTILMD AHB GPKE / GeLi Gas 5.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 13.12.2012 | 01.04.2013 | 30.09.2013 |
UTILMD AHB GPKE / GeLi Gas 5.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 25.01.2013 | 01.04.2013 | 30.09.2013 |
UTILMD AHB GPKE / GeLi Gas 5.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 31.01.2013 | 01.04.2013 | 30.09.2013 |
UTILMD AHB GPKE / GeLi Gas 5.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 23.05.2013 | 31.01.2013 | 30.09.2013 |
UTILMD AHB GPKE / GeLi Gas 5.1 | 01.10.2013 | 31.03.2014 |
UTILMD AHB GPKE / GeLi Gas 5.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 19.09.2013 | 01.10.2013 | 31.03.2014 |
UTILMD AHB GPKE / GeLi Gas 5.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 23.05.2013 | 01.10.2013 | 31.03.2014 |
UTILMD AHB GPKE / GeLi Gas 5.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 01.07.2013 | 01.10.2013 | 31.03.2014 |
UTILMD AHB GPKE / GeLi Gas 5.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 02.08.2013 | 01.10.2013 | 31.03.2014 |
UTILMD AHB GPKE / GeLi Gas 6.0 | 01.04.2014 | 30.09.2014 |
UTILMD AHB GPKE / GeLi Gas 6.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 29.11.2013 | 01.04.2014 | 30.09.2014 |
UTILMD AHB GPKE / GeLi Gas 6.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 13.01.2014 | 01.04.2014 | 30.09.2014 |
UTILMD AHB GPKE / GeLi Gas 6.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 26.03.2014 | 01.04.2014 | 30.09.2014 |
UTILMD AHB GPKE / GeLi Gas 6.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 28.05.2014 | 28.05.2014 | 30.09.2014 |
UTILMD AHB GPKE / GeLi Gas 6.0a | 01.10.2014 | 31.03.2015 |
UTILMD AHB GPKE / GeLi Gas 6.0a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 28.05.2014 | 01.10.2014 | 31.03.2015 |
UTILMD AHB GPKE / GeLi Gas 6.0a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 25.07.2014 | 01.10.2014 | 31.03.2015 |
UTILMD AHB GPKE / GeLi Gas 6.0a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 29.08.2014 | 01.10.2014 | 31.03.2015 |
UTILMD AHB GPKE / GeLi Gas 6.0b | 01.04.2015 | 30.09.2015 |
UTILMD AHB GPKE / GeLi Gas 6.0b Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 20.01.2015 | 01.04.2015 | 30.09.2015 |
UTILMD AHB GPKE / GeLi Gas 6.0c | 01.10.2015 | 31.03.2016 |
UTILMD AHB GPKE / GeLi Gas 6.0d | 01.04.2016 | 30.09.2016 |
UTILMD AHB GPKE / GeLi Gas 6.0d Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 16.03.2016 | 01.04.2016 | 30.09.2016 |
UTILMD AHB GPKE / GeLi Gas 6.0f | 01.10.2017 | 31.03.2019 |
UTILMD AHB GPKE / GeLi Gas 6.0f Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 26.03.2018 | 01.10.2017 | 16.07.2018 |
UTILMD AHB GPKE / GeLi Gas 6.0f Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 17.07.2018 | 01.10.2017 | 31.03.2019 |
UTILMD AHB GPKE / GeLi Gas 6.0g | 01.04.2019 | 30.11.2019 |
UTILMD AHB GPKE / GeLi Gas 6.1 | 01.12.2019 | 31.03.2020 |
UTILMD AHB GPKE / GeLi Gas 6.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.07.2019 | 01.12.2019 | 01.10.2019 |
UTILMD AHB GPKE / GeLi Gas 6.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 02.10.2019 | 01.12.2019 | 10.11.2019 |
UTILMD AHB GPKE / GeLi Gas 6.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 11.11.2019 | 01.12.2019 | 16.12.2019 |
UTILMD AHB GPKE / GeLi Gas 6.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 17.12.2019 | 17.12.2019 | 31.03.2020 |
UTILMD AHB MaBiS 1.0 | 01.04.2011 | 30.09.2011 |
UTILMD AHB MaBiS 1.1 | 01.10.2011 | 30.09.2012 |
UTILMD AHB MaBiS 1.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 02.04.2012 | 01.10.2011 | 30.09.2012 |
UTILMD AHB MaBiS 1.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 30.07.2012 | 01.10.2012 | 30.09.2012 |
UTILMD AHB MaBiS 1.1a | 01.10.2012 | 31.03.2013 |
UTILMD AHB MaBiS 2.0 | 01.04.2013 | 30.09.2013 |
UTILMD AHB MaBiS 2.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 13.12.2012 | 01.04.2013 | 30.09.2013 |
UTILMD AHB MaBiS 2.1 | 01.10.2013 | 31.03.2014 |
UTILMD AHB MaBiS 2.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 23.05.2013 | 01.10.2013 | 31.03.2014 |
UTILMD AHB MaBiS 3.0 | 01.04.2014 | 30.09.2014 |
UTILMD AHB MaBiS 3.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 29.11.2013 | 01.04.2014 | 30.09.2014 |
UTILMD AHB MaBiS 3.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 13.01.2014 | 01.04.2014 | 30.09.2014 |
UTILMD AHB MaBiS 3.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 26.03.2014 | 01.04.2014 | 30.09.2014 |
UTILMD AHB MaBiS 3.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 28.05.2014 | 28.05.2014 | 30.09.2014 |
UTILMD AHB MaBiS 3.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 12.06.2014 | 12.06.2014 | 30.09.2014 |
UTILMD AHB MaBiS 3.0a | 01.10.2014 | 30.04.2015 |
UTILMD AHB MaBiS 3.0a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 28.05.2014 | 01.10.2014 | 30.04.2015 |
UTILMD AHB MaBiS 3.0a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 12.06.2014 | 01.10.2014 | 30.04.2015 |
UTILMD AHB MaBiS 3.0a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 29.08.2014 | 01.10.2014 | 30.04.2015 |
UTILMD AHB MaBiS 3.0a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 30.09.2014 | 01.10.2014 | 30.04.2015 |
UTILMD AHB MaBiS 3.0b | 01.05.2015 | 30.09.2015 |
UTILMD AHB MaBiS 3.0b Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 20.01.2015 | 01.04.2015 | 30.09.2015 |
UTILMD AHB MaBiS 3.0b Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 03.03.2015 | 01.04.2015 | 30.09.2015 |
UTILMD AHB MaBiS 3.0c | 01.10.2015 | 31.03.2016 |
UTILMD AHB MaBiS 3.0d | 01.04.2016 | 30.09.2016 |
UTILMD AHB MaBiS 3.0e | 01.10.2016 | 30.09.2017 |
UTILMD AHB MaBiS 3.0g | 01.04.2019 | 30.11.2019 |
UTILMD AHB MaBiS 3.0f | 01.10.2017 | 31.03.2019 |
UTILMD AHB MaBiS 3.1 | 01.12.2019 | 31.03.2020 |
UTILMD AHB MaBiS 3.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.07.2019 | 01.12.2019 | 01.10.2019 |
UTILMD AHB MaBiS 3.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 02.10.2019 | 01.12.2019 | 10.11.2019 |
UTILMD AHB MaBiS 3.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 11.11.2019 | 01.12.2019 | 16.12.2019 |
UTILMD AHB MaBiS 3.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 17.12.2019 | 17.12.2019 | 31.03.2020 |
UTILMD AHB MaBiS 3.1a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 03.04.2020 | 03.04.2020 | 09.06.2020 |
UTILMD AHB Netzbetreiberwechsel 1.0 | 01.04.2015 | 30.09.2015 |
UTILMD AHB Netzbetreiberwechsel 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 20.01.2015 | 01.04.2015 | 30.09.2015 |
UTILMD AHB Netzbetreiberwechsel 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 22.05.2015 | 01.10.2015 | 30.09.2015 |
UTILMD AHB Netzbetreiberwechsel 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 22.05.2015 | 22.05.2015 | 30.09.2015 |
UTILMD AHB Netzbetreiberwechsel 1.0a | 01.10.2015 | 31.03.2016 |
UTILMD AHB Netzbetreiberwechsel 1.0a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 22.05.2015 | 01.10.2015 | 31.03.2016 |
UTILMD AHB Netzbetreiberwechsel 1.0b | 01.04.2016 | 30.09.2016 |
UTILMD AHB Netzbetreiberwechsel 1.0b Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 05.11.2015 | 01.04.2016 | 30.09.2016 |
UTILMD AHB Netzbetreiberwechsel 1.0c | 01.10.2016 | 30.09.2017 |
UTILMD AHB Netzbetreiberwechsel 1.0d | 01.10.2017 | 31.03.2019 |
UTILMD AHB Netzbetreiberwechsel 1.0d Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 17.07.2018 | 01.10.2017 | 25.10.2018 |
UTILMD AHB Netzbetreiberwechsel 1.0d Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 25.09.2017 | 01.10.2017 | 16.07.2018 |
UTILMD AHB Netzbetreiberwechsel 1.0d Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 26.10.2018 | 01.10.2017 | 31.03.2019 |
UTILMD AHB Netzbetreiberwechsel 1.0e | 01.04.2019 | 30.11.2019 |
UTILMD AHB Netzbetreiberwechsel 1.0e Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 26.10.2018 | 01.04.2019 | 30.11.2019 |
UTILMD AHB Netzbetreiberwechsel 1.1 | 01.12.2019 | 31.03.2020 |
UTILMD AHB Netzbetreiberwechsel 1.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.07.2019 | 01.12.2019 | 01.10.2019 |
UTILMD AHB Netzbetreiberwechsel 1.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 02.10.2019 | 01.12.2019 | 10.11.2019 |
UTILMD AHB Netzbetreiberwechsel 1.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 11.11.2019 | 01.12.2019 | 16.12.2019 |
UTILMD AHB Netzbetreiberwechsel 1.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 17.12.2019 | 17.12.2019 | 31.03.2020 |
UTILMD AHB Stammdatenänderung 1.0 | 01.10.2015 | 31.03.2016 |
UTILMD AHB Stammdatenänderung 1.0a | 01.04.2016 | 30.09.2016 |
UTILMD AHB Stammdatenänderung 1.0b | 01.10.2016 | 30.09.2017 |
UTILMD AHB Stammdatenänderung 1.0c | 01.10.2017 | 31.03.2019 |
UTILMD AHB Stammdatenänderung 1.0c Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 26.03.2018 | 01.10.2017 | 16.07.2018 |
UTILMD AHB Stammdatenänderung 1.0c Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 17.07.2018 | 01.10.2017 | 31.03.2019 |
UTILMD AHB Stammdatenänderung 1.0d | 01.04.2019 | 30.11.2019 |
UTILMD AHB Stammdatenänderung 1.1 | 01.12.2019 | 31.03.2020 |
UTILMD AHB Stammdatenänderung 1.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.07.2019 | 01.12.2019 | 01.10.2019 |
UTILMD AHB Stammdatenänderung 1.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 02.10.2019 | 01.12.2019 | 10.11.2019 |
UTILMD AHB Stammdatenänderung 1.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 11.11.2019 | 01.12.2019 | 20.11.2019 |
UTILMD AHB Stammdatenänderung 1.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 21.11.2019 | 01.12.2019 | 16.12.2019 |
UTILMD AHB Stammdatenänderung 1.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 17.12.2019 | 17.12.2019 | 31.03.2020 |
UTILMD AHB Stammdatenänderung 1.1a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 03.04.2020 | 03.04.2020 | 09.06.2020 |
UTILMD AHB Stammdatenänderung 1.1a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 10.06.2020 | 10.06.2020 | 29.09.2020 |
UTILMD AHB Stammdatenänderung 4.0 | 07.05.2007 | 05.12.2007 |
UTILMD AHB Stammdatenänderung 4.0a | 06.12.2007 | 01.04.2008 |
UTILMD AHB Stammdatenänderung 4.0b | 01.04.2008 | 30.09.2008 |
UTILMD AHB Stammdatenänderung 4.1 | 01.10.2008 | 31.03.2009 |
UTILMD AHB WiM 1.0 | 01.10.2011 | 31.03.2013 |
UTILMD AHB WiM 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.02.2012 | 15.02.2012 | 31.03.2013 |
UTILMD AHB WiM 2.0 | 01.04.2013 | 30.09.2013 |
UTILMD AHB WiM 2.1 | 01.10.2013 | 31.03.2014 |
UTILMD AHB WiM 3.0 | 01.04.2014 | 30.09.2014 |
UTILMD AHB WiM 3.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 13.01.2014 | 01.04.2014 | 30.09.2014 |
UTILMD AHB WiM 3.0a | 01.10.2014 | 31.03.2015 |
UTILMD AHB WiM 3.0a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 29.08.2014 | 01.04.2014 | 31.03.2015 |
UTILMD AHB WiM 3.0b | 01.04.2015 | 30.09.2015 |
UTILMD AHB WiM 3.0c | 01.10.2015 | 31.03.2016 |
UTILMD AHB WiM 3.0d | 01.04.2016 | 30.09.2016 |
UTILMD AHB WiM 3.0e | 01.10.2016 | 30.09.2017 |
UTILMD AHB WiM 3.0e Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 17.06.2016 | 01.10.2016 | 30.09.2017 |
UTILMD AHB WiM 3.0f | 01.10.2017 | 31.03.2019 |
UTILMD AHB WiM 3.0f Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 26.06.2017 | 01.10.2017 | 16.07.2018 |
UTILMD AHB WiM 3.0f Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 17.07.2018 | 01.10.2017 | 31.03.2019 |
UTILMD AHB WiM 3.0f Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 26.03.2018 | 01.10.2017 | 16.07.2018 |
UTILMD AHB WiM 3.0g | 01.04.2019 | 30.11.2019 |
UTILMD AHB WiM 3.1 | 01.12.2019 | 31.03.2020 |
UTILMD AHB WiM 3.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.07.2019 | 01.12.2019 | 01.10.2019 |
UTILMD AHB WiM 3.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 02.10.2019 | 01.12.2019 | 10.11.2019 |
UTILMD AHB WiM 3.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 11.11.2019 | 01.12.2019 | 16.12.2019 |
UTILMD AHB WiM 3.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 17.12.2019 | 17.12.2019 | 31.03.2020 |
UTILMD AHB WiM 3.1a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 03.04.2020 | 03.04.2020 | 09.06.2020 |
UTILTS MIG 1.0 | 01.10.2017 | 31.03.2019 |
UTILTS MIG 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 29.11.2017 | 01.10.2017 | 31.03.2019 |